%define version 0.14.1
%define release 10mdk

%define major 3
%define intllibname %mklibname intl %{major}
%define misclibname %mklibname gettextmisc

%define enable_csharp 0
%{?_with_csharp: %global enable_csharp 1}

Name:		gettext
Summary:	GNU libraries and utilities for producing multi-lingual messages.
Version:	%{version}
Release:	%{release}
License:	GPL
Group:		System/Internationalization
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-buildroot
URL:		http://www.gnu.org/software/gettext/

Source:		ftp://ftp.gnu.org/pub/gnu/%{name}/%{name}-%{version}.tar.gz
Source1:	%{SOURCE0}.sig
Source2:	po-mode-init.el
Patch0:		gettext-0.14.1-libtool-fixes.patch.bz2
# patch to not issue error messages and warnings with some charset encodings
# we support in MDK. -- pablo
Patch5:		%{name}-0.12.1-charsets.patch.bz2
# (Abel) CAN-2004-0966 -- autopoint and gettextize allowing symlink attack
Patch6:		gettext-0.14.1-insecure-temp.patch.bz2
# (Abel) misc CVS fixes after 0.14.1
Patch7:		gettext-0.14.1-cvs-fixes.patch.bz2

Requires:	%{name}-base = %{version}-%{release}
Requires:	%{misclibname} = %{version}-%{release}
# xgettext will dlopen() it when extracting strings from glade files
Requires:	%mklibname expat 0
BuildRequires:  automake1.8
BuildRequires:	autoconf2.5
BuildRequires:	bison
BuildRequires:	flex
BuildRequires:	emacs-bin
BuildRequires:	texinfo
BuildRequires:	gcc-java
BuildRequires:	gcj-tools
%if %enable_csharp
# (Abel) we pick mono here, though pnet can be used as well.
BuildRequires:	mono
%endif

Prereq:		/sbin/install-info

%description
The GNU gettext package provides a set of tools and documentation for producing
multi-lingual messages in programs. Tools include a set of conventions about
how programs should be written to support message catalogs, a directory and
file naming organization for the message catalogs, a runtime library which
supports the retrieval of translated messages, and stand-alone programs for
handling the translatable and the already translated strings. Gettext provides
an easy to use library and tools for creating, using, and modifying natural
language catalogs and is a powerful and simple method for internationalizing
programs.

If you would like to internationalize or incorporate multi-lingual messages
into programs that you're developing, you should install gettext.

Build Option:
--with csharp          Enables C# support in gettext

%package	-n %{intllibname}
Summary:	Basic libintl library for internationalization
Group:		System/Libraries
License:	LGPL
Provides:	libintl

%description	-n %{intllibname}
This package contains the libintl library, which is important for
system internationalization.

%package	-n %{misclibname}
Summary:	Other %{name} libraries needed by %{name} utilities
Group:		System/Libraries
License:	LGPL

%description	-n %{misclibname}
This package contains all other libraries used by %{name} utilities,
and are not very widely used outside %{name}.

%package	devel
Summary:	Development files for %{name}
Group:		Development/C
License:	LGPL
Requires:	%{name} = %{version}-%{release}
Prereq:		/sbin/install-info

%description	devel
This package contains all development related files necessary for
developing or compiling applications/libraries that needs
internationalization capability. You also need this package if you
want to add gettext support for your project.

%package	base
Summary:	Basic binary for showing translation of textual messages
Group:		System/Internationalization
Requires:	%{intllibname} = %{version}-%{release}

%description	base
This package contains the basic binary from %{name}. It is splitted from
%{name} because initscript need it to show translated boot messages.

%package	java
Summary:	Java binding for GNU gettext.
Group:		System/Internationalization
Requires:	%{name} = %{version}-%{release}

%description	java
This package contains class file that implements the main GNU libintl
functions in Java. This allows compiling GNU gettext message catalogs
into Java ResourceBundle classes.

%package	csharp
Summary:	C# binding for GNU gettext
Group:		System/Internationalization
Requires:	mono

%description	csharp
This package contains class file that implements the main GNU libintl
functions in C#. This allows compiling GNU gettext message catalogs
into C# dll or resource files.

%prep
%setup -q
%patch0 -p1 -b .libtool-fixes
%patch5 -p1 -b .more_charsets
%patch6 -p1 -b .symlink-attack
%patch7 -p1 -b .cvs-fixes

# needed by patch0
(cd gettext-runtime/libasprintf && autoconf)

%build
%configure2_5x \
	--enable-shared \
	--with-included-gettext \
%if %enable_csharp
	--enable-csharp=mono \
%else
	--disable-csharp \
%endif

%make

# (Abel) success/fail depends on locale. E.g. if locales-fa is not installed,
# then format-c-5 test fails. And lang-perl-1 will always fail, because it
# was assumed that fr_FR = fr_FR.ISO-8859-1, but right now fr_FR uses
# ISO-8859-15 by default here.
# make check

%install
rm -rf $RPM_BUILD_ROOT
%makeinstall_std

# fix file permissions
chmod +x $RPM_BUILD_ROOT%{_bindir}/gettext.sh

# remove unwanted files
rm -f $RPM_BUILD_ROOT%{_includedir}/libintl.h \
      $RPM_BUILD_ROOT%{_datadir}/locale/locale.alias
rm -f gettext-runtime/intl-java/javadoc2/package-list

install -D -m 644 %{SOURCE2} $RPM_BUILD_ROOT%{_sysconfdir}/emacs/site-start.d/%{name}.el

# remove non-standard lc directories
for i in en@boldquot en@quot ; do rm -rf $RPM_BUILD_ROOT/%{_datadir}/locale/$i; done

# move installed doc back to %%doc
rm -rf htmldoc examples
mkdir htmldoc
for i in gettext-runtime/man/*.html; do
  rm -f $RPM_BUILD_ROOT%{_datadir}/doc/gettext/`basename $i`
done
rm -rf $RPM_BUILD_ROOT%{_datadir}/doc/gettext/javadoc*
mv $RPM_BUILD_ROOT%{_datadir}/doc/gettext/* $RPM_BUILD_ROOT/%{_datadir}/doc/libasprintf/* htmldoc
mv htmldoc/examples examples

# move crucial stuff to /lib and /bin
pushd $RPM_BUILD_ROOT
mkdir -p bin
mkdir -p ./%{_lib}
mv usr/bin/gettext bin/
ln -s ../../bin/gettext usr/bin/gettext
mv .%{_libdir}/libintl.so.* ./%{_lib}/
rm -f .%{_libdir}/libintl.so
# if major changed, then package build will fail, which is a GOOD THING.
# this prevents mindless packaging.
[ -f %{_lib}/libintl.so.%{major} ] && \
  ln -s ../../%{_lib}/libintl.so.%{major} .%{_libdir}/libintl.so
popd

%find_lang %{name} --all-name

%clean
rm -rf $RPM_BUILD_ROOT

%post
%_install_info %{name}.info

%preun
%_remove_install_info %{name}.info

%post devel
%_install_info autosprintf.info

%preun devel
%_remove_install_info autosprintf.info

%post -n %{intllibname} -p /sbin/ldconfig
%postun -n %{intllibname} -p /sbin/ldconfig

%post -n %{misclibname} -p /sbin/ldconfig
%postun -n %{misclibname} -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc AUTHORS README COPYING gettext-runtime/ABOUT-NLS gettext-runtime/BUGS NEWS THANKS gettext-tools/TODO htmldoc
%config(noreplace) %{_sysconfdir}/emacs/site-start.d/*.el
%{_bindir}/envsubst
%{_bindir}/gettext.sh
%{_bindir}/msg*
%{_bindir}/xgettext
%{_bindir}/autopoint
%dir %{_datadir}/gettext
%{_datadir}/%{name}/msgunfmt.tcl
%{_datadir}/%{name}/projects
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/hostname
%{_libdir}/%{name}/project-id
%{_libdir}/%{name}/urlget
%{_libdir}/%{name}/user-email
%exclude %{_libdir}/%{name}/gnu.gettext.*
%{_infodir}/gettext.*
%{_datadir}/emacs/site-lisp/*.el*
%{_mandir}/man1/envsubst.*
%{_mandir}/man1/msg*
%{_mandir}/man1/xgettext.*
%{_mandir}/man1/autopoint.*

%files base -f %{name}.lang
%defattr(-,root,root)
%doc gettext-runtime/man/*.1.html
/bin/gettext
%{_bindir}/gettext
%{_bindir}/ngettext
%{_mandir}/man1/gettext*
%{_mandir}/man1/ngettext*

%files -n %{intllibname}
%defattr(-,root,root)
%doc gettext-runtime/intl/COPYING*
/%{_lib}/lib*.so.*

%files -n %{misclibname}
%defattr(-,root,root)
%doc gettext-runtime/intl/COPYING*
%{_libdir}/lib*-*.*.so
%{_libdir}/lib*.so.*

%files devel
%defattr(-,root,root)
%doc gettext-runtime/man/*.3.html examples
%{_bindir}/gettextize
%{_datadir}/%{name}/ABOUT-NLS
%{_datadir}/%{name}/archive.tar.gz
%{_datadir}/%{name}/config.rpath
%{_datadir}/%{name}/*.h
%{_datadir}/%{name}/intl
%{_datadir}/%{name}/mkinstalldirs
%{_datadir}/%{name}/po
%{_datadir}/aclocal/*
%{_includedir}/*
%{_infodir}/autosprintf*
%{_libdir}/lib*.a
%{_libdir}/lib*.la
# "lib*.so" cannot be used (it should be 'lib[^\.]*\.so' regexp in fact
# but using regexp is not possible here; so we list all files manually
%{_libdir}/libasprintf.so
%{_libdir}/libgettextlib.so
%{_libdir}/libgettextpo.so
%{_libdir}/libgettextsrc.so
%{_libdir}/libintl.so
%{_mandir}/man3/*

%files java
%defattr(-,root,root)
%doc gettext-runtime/intl-java/javadoc*
%{_libdir}/%{name}/gnu.gettext.*
%{_datadir}/%{name}/*.jar

%if %enable_csharp
%files csharp
%defattr(-,root,root)
%doc gettext-runtime/intl-csharp/csharpdoc/*
%{_libdir}/*.dll
%{_libdir}/gettext/*.exe
%endif

%changelog
* Fri Nov 26 2004 Abel Cheung <deaddog@mandrake.org> 0.14.1-10mdk
- P6: fix CAN-2004-0966 (scripts allow symlink attack on temp files)
- P7: assorted CVS fixes
- Split C# stuff into another package if people really compile RPM with C# support

* Mon Sep 20 2004 Christiaan Welvaart <cjw@daneel.dyndns.org> 0.14.1-9mdk
- fix buildrequires (automake1.7 -> automake1.8)

* Tue Jul 27 2004 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 0.14.1-8mdk
- merge from amd64-branch: fix broken built-in libtool

* Thu Jun  3 2004 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 0.14.1-7mdk
- rebuild against gcc3.4

* Mon May 31 2004 Götz Waschk <waschk@linux-mandrake.com> 0.14.1-6mdk
- fix emacs site-start file

* Sat May 22 2004 Abel Cheung <deaddog@deaddog.org> 0.14.1-5mdk
- Drop patch0 (libtool) and patch1 (newer javac don't output error when
  copying class file onto itself anymore)
- Can optionally build C# support (using mono)

* Fri Apr 23 2004 Thierry Vignaud <tvignaud@mandrakesoft.com> 0.14.1-4mdk
- fix %%_libdir/libintl.so link

* Wed Apr 21 2004 Götz Waschk <waschk@linux-mandrake.com> 0.14.1-3mdk
- fix emacs site-start script

* Mon Apr 19 2004 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 0.14.1-2mdk
- fix provides (from Charles A Edwards <eslrahc@bellsouth.net>)

* Sun Apr 18 2004 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 0.14.1-1mdk
- 0.14.1
- bump major to 3
- nuke unpackaged files

* Sun Jan 11 2004 Abel Cheung <deaddog@deaddog.org> 0.13.1-1mdk
- New version
- Merge some changes by Charles A Edwards <eslrahc at bellsouth.net>
- Remove patch7 (LSB requirement), LSB is going to accommodate current
  gettext behavior
- All other patchs obsolete or in CVS, except patch5 (extra charset)
- Split java files into subpackage, to avoid gcj dependency on main pkg
- Patch0: Fix libtool 1.5 DESTDIR issue
- Patch1: Avoid "-d ." argument for javacomp.sh, javac from gcc 3.3
  really dislike it -- moving class file onto itself causes error
- Split shared library other than libintl into another package,
  to keep crucial package small (thanks titi and gb for input)
- Various other cleanup
- Parallel make works now

* Wed Jul  9 2003 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 0.11.5-7mdk
- Rebuild

* Tue Jun 03 2003 Stew Benedict <sbenedict@mandrakesoft.com> 0.11.5-6mdk
- LSB/LI18NUX test requirements - patch7
- (msgfmt ignore duplicate strings in multiple domains when -o specified)
- BuildRequires: emacs-el, use %%mklibname

* Thu May 08 2003 Stefan van der Eijk <stefan@eijk.nu> 0.11.5-5mdk
- BuildRequires: autoconf2.5 bison

* Mon Apr 28 2003 Guillaume Cottenceau <gc@mandrakesoft.com> 0.11.5-4mdk
- don't install java binaries to not depend on libgcj

* Fri Apr 25 2003 Guillaume Cottenceau <gc@mandrakesoft.com> 0.11.5-3mdk
- use %%configure2_5x

* Fri Dec 20 2002 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 0.11.5-2mdk
- Rebuild

* Fri Dec 13 2002 Guillaume Cottenceau <gc@mandrakesoft.com> 0.11.5-1mdk
- shamelessly use work from Austin Acton <aacton@yorku.ca>:
  - bump version and libver
  - don't run autoconf explicitly (fails)
  - replace patch 2 (arm*-*) with perl command (easier updates)
  - add autopoint, and new files in libdir/gettext and datadir/emacs

* Tue Aug 27 2002 Pablo Saratxaga <pablo@mandrakesoft.com> 0.11.2-8mdk
- patch to avoid segfaults on unknown encodings

* Mon Jul 08 2002 Stefan van der Eijk <stefan@eijk.nu> 0.11.2-7mdk
- BuildRequires: emacs-bin

* Sun Jul  7 2002 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 0.11.2-6mdk
- rpmlint fixes: hardcoded-library-path

* Thu Jul  4 2002 Guillaume Cottenceau <gc@mandrakesoft.com> 0.11.2-5mdk
- try to fix %%makeinstall call so that there are no missing files in
  po subdir (use %%makeinstall_std and don't specify additional
  directories)

* Mon Jun  3 2002 Guillaume Cottenceau <gc@mandrakesoft.com> 0.11.2-4mdk
- use work from Götz Waschk <waschk@linux-mandrake.com>
  - change requires to %%version-%%release
  - update source 1 (emacs po-mode init)
  - fix libintl version number to 2.0.1
- fix silly html doc in /usr/doc/gettext -> %%docdir/htmldoc

* Sat Jun  1 2002 Stefan van der Eijk <stefan@eijk.nu> 0.11.2-3mdk
- BuildRequires
- fix release on previous changelog (1mdk --> 2mdk)

* Mon May 27 2002 Pablo Saratxaga <pablo@mandrakesoft.com> 0.11.2-2mdk
- moved shared libs to the libintl sub-package

* Thu May 23 2002 Pablo Saratxaga <pablo@mandrakesoft.com> 0.11.2-1mdk
- updated to 0.11.2
- increased major number

* Wed Oct 17 2001 Guillaume Cottenceau <gc@mandrakesoft.com> 0.10.40-3mdk
- fix no-documentation

* Mon Oct 15 2001 Guillaume Cottenceau <gc@mandrakesoft.com> 0.10.40-2mdk
- fix invalid-lc-messages-dir
- fix patch-not-applied
- fix obsolete-tag Copyright
- revive three Patches (please packagers -> when a patch don't "pass"
  anymore, don't just ignore it, do your work!!)
- use RH site-start Emacs resource file for po-mode
- more docs

* Fri Sep 28 2001 Guillaume Cottenceau <gc@mandrakesoft.com> 0.10.40-1mdk
- new version

* Wed Sep 12 2001 Guillaume Cottenceau <gc@mandrakesoft.com> 0.10.39-2mdk
- mark emacs site-start file as conffile

* Tue Jul 31 2001 Pablo Saratxaga <pablo@mandrakesoft.com> 0.10.39-1mdk
- update to 0.10.39

* Thu Jul  5 2001 Guillaume Cottenceau <gc@mandrakesoft.com> 0.10.38-2mdk
- rebuild

* Tue May 29 2001 Frederic Crozat <fcrozat@mandrakesoft.com> 0.10.38-1mdk
- Release 0.10.38 (should correct po/Makefile generation problem)
- Add man pages
- No longer ship charset.alias, it was wrongly generated with previous version
(and it is not needed for system with glibc >= 2.1)

* Tue May 15 2001 Pablo Saratxaga <pablo@mandrakesoft.com> 0.10.37-3mdk
- small patch to avoid issuing warning messages fro charsets we do support

* Fri May 11 2001 Geoffrey Lee <snailtalk@mandrakesoft.com> 0.10.37-2mdk
- Fix a dangling symlink (Abel).

* Fri Apr 20 2001 Geoffrey Lee <snailtalk@mandrakesoft.com> 0.10.37-1mdk
- GNU gettext 0.10.37.
- Include the charset.alias file.

* Wed Apr 18 2001 Geoffrey Lee <snailtalk@mandrakesoft.com> 0.10.36-1mdk
- New and shiny 0.10.36.
- Patch cleanup.
- Split out the dynamic libraries.
- Remove msghack but put in ngettext.
- Don't run aclocal before ./configure.
- Use %%version in the Source tag instead of a hardcoded one.
- In the Source tag s/alpha/ftp/;

* Tue Apr 17 2001 Guillaume Cottenceau <gc@mandrakesoft.com> 0.10.35-20mdk
- move /usr/bin/gettext to /bin/gettext so that initscripts can be
  translated before /usr is ever mounted

* Tue Apr 17 2001 Jeff Garzik <jgarzik@mandrakesoft.com> 0.10.35-19mdk
- Move gettextize to devel package
- Install po/Makefile.in.in in /usr/share/gettext/po.
  gettextize was broken without this.
- Install ABOUT-NLS in /usr/share/gettext.
  gettextize was broken without this.

* Thu Mar 22 2001 Guillaume Cottenceau <gc@mandrakesoft.com> 0.10.35-18mdk
- split main package because initscripts requires gettext binary, and we
  want to have a reasonable "smallest" install
- add emacs site-start for el file
- remove elc version of the mode

* Tue Nov  7 2000 Guillaume Cottenceau <gc@mandrakesoft.com> 0.10.35-17mdk
- fix dependency on devel package
- add documentation

* Wed Aug 23 2000 Guillaume Cottenceau <gc@mandrakesoft.com> 0.10.35-16mdk
- automatically added packager tag

* Tue Aug 22 2000 Guillaume Cottenceau <gc@mandrakesoft.com> 0.10.35-15mdk
- bugfixed gettextize when headers are not there
  thanks to <rchaillat@mandrakesoft.com>

* Tue Jul 18 2000 Guillaume Cottenceau <gc@mandrakesoft.com> 0.10.35-14mdk
- macros

* Fri May  5 2000 Guillaume Cottenceau <gc@mandrakesoft.com> 0.10.35-13mdk
- quick patch to have it work!

* Sat Apr 08 2000 John Buswell <johnb@mandrakesoft.com> 0.10.35-12mdk
- added devel package

* Thu Mar 30 2000 John Buswell <johnb@mandrakesoft.com> 0.10.35-11mdk
- fixed groups
- Removed version number from spec filename
- spec-helper

* Tue Nov 02 1999 Pablo Saratxaga <pablo@mandrakesoft.com>
- rebuild for new environment

* Wed Jun 30 1999 Chmouel Boudjnah <chmouel@mandrakesoft.com>
- s/arch-RedHat/arch-Mandrake/
- msghack updates.

* Tue May 11 1999 Bernhard Rosenkraenzer <bero@mandrakesoft.com>
- Mandrake adaptions

* Sun Mar 21 1999 Cristian Gafton <gafton@redhat.com> 
- auto rebuild in the new build environment (release 8)

* Mon Mar 08 1999 Cristian Gafton <gafton@redhat.com>
- added patch for misc hacks to facilitate rpm translations

* Thu Dec 03 1998 Cristian Gafton <gafton@redhat.com>
- patch to allow to build on ARM

* Wed Sep 30 1998 Jeff Johnson <jbj@redhat.com>
- add Emacs po-mode.el files.

* Sun Sep 13 1998 Cristian Gafton <gafton@redhat.com>
- include the aclocal support files

* Fri Sep  3 1998 Bill Nottingham <notting@redhat.com>
- remove devel package (functionality is in glibc)

* Tue Sep  1 1998 Jeff Johnson <jbj@redhat.com>
- update to 0.10.35.

* Mon Jun 29 1998 Jeff Johnson <jbj@redhat.com>
- add gettextize.
- create devel package for libintl.a and libgettext.h.

* Mon Apr 27 1998 Prospector System <bugs@redhat.com>
- translations modified for de, fr, tr

* Sun Nov 02 1997 Cristian Gafton <gafton@redhat.com>
- added info handling
- added misc-patch (skip emacs-lisp modofications)

* Sat Nov 01 1997 Erik Troan <ewt@redhat.com>
- removed locale.aliases as we get it from glibc now
- uses a buildroot

* Mon Jun 02 1997 Erik Troan <ewt@redhat.com>
- Built against glibc
